Installation
=============

Quick and Easy
--------------
from the source:

    python setup.py install

Or using pip:

    pip install QuickWeb

Requirements
------------
The following python version and libraries are required:

* Python3
* Jinja2
* CherryPy
* docopt
* Requests

